@@ -30,11 +30,12 @@ namespace gloox
     };
 
     ICEUDP::ICEUDP( const std::string& pwd, const std::string& ufrag, CandidateList& candidates )
-      : m_pwd( pwd ), m_ufrag( ufrag), m_candidates( candidates )
+      : Plugin( PluginICEUDP ), m_pwd( pwd ), m_ufrag( ufrag), m_candidates( candidates )
     {
     }
 
     ICEUDP::ICEUDP( const Tag* tag )
+      : Plugin( PluginICEUDP )
     {
       if( !tag || tag->name() != "transport" || tag->xmlns() != XMLNS_JINGLE_ICE_UDP )
         return;
@@ -58,6 +59,7 @@ namespace gloox
         c.rel_addr = (*it)->findAttribute( "rel-addr" );
         c.rel_port = atoi( (*it)->findAttribute( "rel-port" ).c_str() );
         c.type = (Type)util::lookup( (*it)->findAttribute( "type" ), typeValues );
+        m_candidates.push_back( c );
       }
     }
 
