@@ -78,11 +78,12 @@ namespace gloox
     Session::Reason::Reason( Reasons reason,
                              const std::string& sid,
                              const std::string& text)
-      : m_reason( reason ), m_sid( sid ), m_text( text )
+      : Plugin( PluginReason ), m_reason( reason ), m_sid( sid ), m_text( text )
     {
     }
 
     Session::Reason::Reason( const Tag* tag )
+      : Plugin( PluginReason )
     {
       if( !tag || tag->name() != "reason" )
         return;
@@ -127,21 +128,23 @@ namespace gloox
     // ---- ~Session::Reason ----
 
     // ---- Session::Jingle ----
-    Session::Jingle::Jingle( Action action, const JID& initiator,
+    Session::Jingle::Jingle( Action action, const JID& initiator, const JID& responder,
                              const PluginList& plugins, const std::string& sid )
       : StanzaExtension( ExtJingle ), m_action( action ), m_sid( sid ),
-        m_initiator( initiator ), m_plugins( plugins ), m_tag( 0 )
+        m_initiator( initiator ), m_responder( responder ), m_plugins( plugins ), m_tag( 0 )
     {
     }
 
-    Session::Jingle::Jingle( Action action, const JID& initiator,
+#ifdef JINGLE_TEST
+    Session::Jingle::Jingle( Action action, const JID& initiator, const JID& responder,
                              const Plugin* plugin, const std::string& sid )
       : StanzaExtension( ExtJingle ), m_action( action ), m_sid( sid ),
-        m_initiator( initiator ), m_tag( 0 )
+        m_initiator( initiator ), m_responder( responder ), m_tag( 0 )
     {
       if( plugin )
         m_plugins.push_back( plugin );
     }
+#endif
 
     Session::Jingle::Jingle( const Tag* tag )
       : StanzaExtension( ExtJingle ), m_action( InvalidAction ), m_tag( 0 )
@@ -154,15 +157,6 @@ namespace gloox
       m_responder.setJID( tag->findAttribute( "responder" ) );
       m_sid = tag->findAttribute( "sid" );
 
-//       const TagList& l = tag->children();
-//       TagList::const_iterator it = l.begin();
-//       for( ; it != l.end(); ++it )
-//       {
-//         const std::string& name = (*it)->name();
-//         if( name == "content" )
-//           m_plugins.push_back( new Content( (*it) ) );
-//       }
-
       m_tag = tag->clone();
     }
 
@@ -219,30 +213,25 @@ namespace gloox
 
     // ---- Session ----
     Session::Session( ClientBase* parent, const JID& callee, SessionHandler* jsh )
-      : m_parent( parent ), m_state( Ended ), m_callee( callee ),
+      : m_parent( parent ), m_state( Ended ), m_remote( callee ),
         m_handler( jsh ), m_valid( false )
     {
-      if( !m_parent || !m_handler || !m_callee )
+      if( !m_parent || !m_handler || !m_remote )
         return;
 
       m_initiator = m_parent->jid();
       m_sid = m_parent->getID();
 
-//       m_parent->registerIqHandler( this, ExtJingle );
-
       m_valid = true;
     }
 
-    Session::Session( ClientBase* parent, const Session::Jingle* jingle, SessionHandler* jsh )
+    Session::Session( ClientBase* parent, const JID& callee, const Session::Jingle* jingle, SessionHandler* jsh )
       : m_parent( parent ), m_state( Ended ), m_handler( jsh ), m_valid( false )
     {
-      if( !m_parent || !m_handler /*|| !jingle || jingle->action() != SessionInitiate*/ )
+      if( !m_parent || !m_handler || !callee /*|| jingle->action() != SessionInitiate*/ )
         return;
 
-//       m_parent->registerIqHandler( this, ExtJingle );
-      m_callee = m_parent->jid();
-//       m_initiator = jingle->initiator();
-//       m_state = Pending;
+      m_remote = callee;
       m_sid = jingle->sid();
 
       m_valid = true;
@@ -327,6 +316,15 @@ namespace gloox
       return doAction( SessionAccept, content );
     }
 
+    bool Session::sessionAccept( const PluginList& plugins )
+    {
+      if( plugins.empty() || m_state >= Pending )
+        return false;
+
+      m_state = Active;
+      return doAction( SessionAccept, plugins );
+    }
+
     bool Session::sessionInfo( const Plugin* info )
     {
       if( m_state < Pending )
@@ -407,8 +405,8 @@ namespace gloox
       if( !m_valid || !m_parent )
         return false;
 
-      IQ init( IQ::Set, m_callee, m_parent->getID() );
-      init.addExtension( new Jingle( action, m_initiator, plugins, m_sid ) );
+      IQ init( IQ::Set, m_remote, m_parent->getID() );
+      init.addExtension( new Jingle( action, m_initiator, m_responder, plugins, m_sid ) );
       m_parent->send( init, this, action );
 
       return true;
@@ -417,17 +415,20 @@ namespace gloox
     bool Session::handleIq( const IQ& iq )
     {
       const Jingle* j = iq.findExtension<Jingle>( ExtJingle );
-      if( !j || j->sid() != m_sid || !m_handler )
+      if( !j || j->sid() != m_sid || !m_handler || !m_parent )
         return false;
 
       switch( j->action() )
       {
         case SessionAccept:
           m_state = Active;
+          m_responder = j->responder();
           break;
         case SessionInitiate:
           m_state = Pending;
           m_initiator = j->initiator();
+          if( !m_responder )
+            m_responder = m_parent->jid();
           break;
         case SessionTerminate:
           m_state = Ended;
@@ -436,11 +437,11 @@ namespace gloox
           break;
       }
 
-      m_handler->handleSessionAction( j->action(), this, j );
-
       IQ re( IQ::Result, iq.from(), iq.id() );
       m_parent->send( re );
 
+      m_handler->handleSessionAction( j->action(), this, j );
+
       return true;
     }
 
