@@ -173,12 +173,6 @@ namespace gloox
       const unsigned char c = data[i];
 //       printf( "found char:   %c, ", c );
 
-      if( !isValid( c ) )
-      {
-        cleanup();
-        return static_cast<int>( i );
-      }
-
       switch( m_state )
       {
         case Initial:
@@ -801,11 +795,6 @@ namespace gloox
     m_preamble = 0;
   }
 
-  bool Parser::isValid( unsigned char c )
-  {
-    return ( c != 0xc0 || c != 0xc1 || c < 0xf5 );
-  }
-
   bool Parser::isWhitespace( unsigned char c )
   {
     return ( c == 0x09 || c == 0x0a || c == 0x0d || c == 0x20 );
